@@ -5,22 +5,18 @@
 <context>
     <name>harmattan</name>
     <message>
-        <location line="+1"/>
         <source>Yes</source>
         <translation>Да</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>No</source>
         <translation>Нет</translation>
     </message>
     <message>
-        <location line="+9"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
@@ -393,7 +389,12 @@
         <translation>Время до станции:</translation>
     </message>
     <message>
-        <location line="+46"/>
+        <location line="+104"/>
+        <source> min.</source>
+        <translation> мин.</translation>
+    </message>
+    <message>
+        <location line="-58"/>
         <source>Description</source>
         <translation>Описание</translation>
     </message>
@@ -690,7 +691,12 @@ Want to download more cities?</source>
         <translation>Интерфейс</translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+47"/>
+        <source>Skin</source>
+        <translation>Оформление</translation>
+    </message>
+    <message>
+        <location line="-8"/>
         <source>Custom font and style for station</source>
         <translation>Настраиваемый шрифт для станции</translation>
     </message>
@@ -1039,7 +1045,17 @@ Want to download more cities?</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+32"/>
+        <source>Author of skin</source>
+        <translation>Автор оформления</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Happy New Year!</source>
+        <translation>С Новым годом!</translation>
+    </message>
+    <message>
+        <location line="-1"/>
         <source>Unknown author</source>
         <translation>Неизвестный автор</translation>
     </message>
