@@ -31,6 +31,9 @@
 #include <QList>
 #include <QMouseEvent>
 #include <QScrollBar>
+#include <QtGui/QGraphicsView>
+#include <QtGui/QGraphicsScene>
+ #include <QGraphicsSceneMouseEvent>
 //#include <QWebFrame>
 //#include <QWebView>
 
@@ -72,7 +75,8 @@ void FlickCharm::activateOn(QWidget *widget)
         scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
         QWidget *viewport = scrollArea->viewport();
-
+//        viewport->grabGesture(Qt::PinchGesture);
+//        viewport->setAttribute(Qt::WA_AcceptTouchEvents);
         viewport->installEventFilter(this);
         scrollArea->installEventFilter(this);
 
@@ -175,27 +179,44 @@ static QPoint deaccelerate(const QPoint &speed, int a = 1, int max = 64)
 
 bool FlickCharm::eventFilter(QObject *object, QEvent *event)
 {
-    if (!object->isWidgetType())
-        return false;
+ if (!object->isWidgetType()) return false;
+ QEvent::Type type = event->type();
 
-    QEvent::Type type = event->type();
-    if (type != QEvent::MouseButtonPress &&
-            type != QEvent::MouseButtonRelease &&
-            type != QEvent::MouseMove)
-        return false;
+ if(type!=QEvent::MouseButtonPress &&
+    type!=QEvent::MouseButtonRelease &&
+    type!=QEvent::MouseMove &&
 
-    QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent*>(event);
-    if (!mouseEvent || mouseEvent->modifiers() != Qt::NoModifier)
-        return false;
+    type!=QEvent::Gesture &&
+    type!=QEvent::TouchBegin &&
+    type!=QEvent::TouchUpdate &&
+    type!=QEvent::TouchEnd)  return false;
+
+ QList<QTouchEvent::TouchPoint> touchPoints;
+ if(type==QEvent::Gesture)
+ {
+  QTouchEvent *touchEvent=dynamic_cast<QTouchEvent*>(event);
+  if(touchEvent) touchPoints = touchEvent->touchPoints();
+ }
+
+ QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
+ QPoint mpos=(touchPoints.count()>0 ? touchPoints.first().pos().toPoint():mouseEvent->pos());
+
+ //if(!mouseEvent || mouseEvent->modifiers() != Qt::NoModifier) return false;
+ if(mouseEvent->modifiers() == Qt::ControlModifier) return false;
 
     QWidget *viewport = dynamic_cast<QWidget*>(object);
     FlickData *data = d->flickData.value(viewport);
-
-//    if (type == QEvent::Gesture) {}
-
     if (!viewport || !data || data->ignored.removeAll(event))
         return false;
 
+    if(type==QEvent::Gesture )
+    if(static_cast<QGestureEvent*>(event)->gesture(Qt::PinchGesture))
+    {
+     data->state = FlickData::Steady;
+     data->speed = QPoint(0,0);
+     return 0;
+    }
+
     bool consumed = false;
     switch (data->state) {
 
@@ -204,7 +225,7 @@ bool FlickCharm::eventFilter(QObject *object, QEvent *event)
             if (mouseEvent->buttons() == Qt::LeftButton) {
                 consumed = true;
                 data->state = FlickData::Pressed;
-                data->pressPos = mouseEvent->pos();
+                data->pressPos = mpos;
                 data->offset = scrollOffset(data->widget);
             }
         break;
@@ -213,16 +234,55 @@ bool FlickCharm::eventFilter(QObject *object, QEvent *event)
         if (mouseEvent->type() == QEvent::MouseButtonRelease) {
             consumed = true;
             data->state = FlickData::Steady;
+//            if(viewport->parent()->metaObject()->className()==QString("TMapView").toAscii())
+//            {
+//             qDebug() << 1;
+//             QGraphicsSceneMouseEvent press(QEvent::GraphicsSceneMousePress);
+//             QGraphicsSceneMouseEvent release(QEvent::GraphicsSceneMouseRelease);
+////             QGraphicsSceneMouseEvent *sceneEvent=(QGraphicsSceneMouseEvent*)event;
+//             qDebug() << 2;
+//             press.setScenePos(mpos);
+//             press.setScreenPos(QCursor::pos());
+//             press.setButton(Qt::LeftButton);
+//             press.setPos(mpos);
+//qDebug() << 2.2;
+//             release.setScenePos(mpos);
+//             release.setScreenPos(QCursor::pos());
+//             release.setButton(Qt::LeftButton);
+//             release.setPos(mpos);
 
-            QMouseEvent *event1 = new QMouseEvent(QEvent::MouseButtonPress,
-                                                  data->pressPos, Qt::LeftButton,
-                                                  Qt::LeftButton, Qt::NoModifier);
-            QMouseEvent *event2 = new QMouseEvent(*mouseEvent);
+//             QGraphicsView *view = (QGraphicsView*)viewport->parent();
+//            qDebug() << 2.5;
+//             QGraphicsScene *scene = view->scene();
+//             qDebug() << 2.6;
+////             QList<QGraphicsItem*> items = scene->items();
+
+////             Q_FOREACH(QGraphicsItem * item, items )
+//             {
+//              //QGraphicsItem * widget = static_cast<QGraphicsWidget*>(item);
+//QGraphicsItem * item=scene->itemAt(mpos);
+//              // Send event to the receivers
+
+//QMouseEvent *event1 = new QMouseEvent(QEvent::MouseButtonPress,mpos,Qt::LeftButton,Qt::LeftButton, Qt::NoModifier);
+//QMouseEvent *event2 = new QMouseEvent(*mouseEvent);
+//data->ignored << event1;
+//data->ignored << event2;
+//              scene->sendEvent(item, event1);
+//              scene->sendEvent(item, event2);
+//              qDebug() << item;
+//             }
+//            }
+//            else
+            {
+
+             QMouseEvent *event1 = new QMouseEvent(QEvent::MouseButtonPress,mpos,Qt::LeftButton,Qt::LeftButton, Qt::NoModifier);
+             QMouseEvent *event2 = new QMouseEvent(*mouseEvent);
+             data->ignored << event1;
+             data->ignored << event2;
+             QApplication::postEvent(object, event1);
+             QApplication::postEvent(object, event2);
+            }
 
-            data->ignored << event1;
-            data->ignored << event2;
-            QApplication::postEvent(object, event1);
-            QApplication::postEvent(object, event2);
         }
         if (mouseEvent->type() == QEvent::MouseMove) {
             consumed = true;
@@ -236,7 +296,7 @@ bool FlickCharm::eventFilter(QObject *object, QEvent *event)
     case FlickData::ManualScroll:
         if (mouseEvent->type() == QEvent::MouseMove) {
             consumed = true;
-            QPoint delta = mouseEvent->pos() - data->pressPos;
+            QPoint delta = mpos - data->pressPos;
             setScrollOffset(data->widget, data->offset - delta);
         }
         if (mouseEvent->type() == QEvent::MouseButtonRelease) {
@@ -250,7 +310,7 @@ bool FlickCharm::eventFilter(QObject *object, QEvent *event)
             consumed = true;
             data->state = FlickData::Stop;
             data->speed = QPoint(0, 0);
-            data->pressPos = mouseEvent->pos();
+            data->pressPos = mpos;
             data->offset = scrollOffset(data->widget);
         }
         if (mouseEvent->type() == QEvent::MouseButtonRelease) {
@@ -298,10 +358,22 @@ void FlickCharm::timerEvent(QTimerEvent *event)
         if (data->state == FlickData::AutoScroll) {
             count++;
             data->speed = deaccelerate(data->speed);
-            QPoint p = scrollOffset(data->widget);
+            QAbstractScrollArea *scrollArea = dynamic_cast<QAbstractScrollArea*>(data->widget);
+
+            QPoint p = QPoint(scrollArea->horizontalScrollBar()->value(),scrollArea->verticalScrollBar()->value()); //scrollOffset(data->widget);
             setScrollOffset(data->widget, p - data->speed);
-            if (data->speed == QPoint(0, 0))
-                data->state = FlickData::Steady;
+            p = QPoint(scrollArea->horizontalScrollBar()->value(),scrollArea->verticalScrollBar()->value());
+            if (data->speed == QPoint(0, 0) ||
+                p.x() < 0 || p.y() < 0 ||
+                (p.x() && p.x() >= scrollArea->horizontalScrollBar()->maximum()) ||
+                (p.y() && p.y() >= scrollArea->verticalScrollBar()->maximum()) )
+            {
+             data->state = FlickData::Steady;
+             data->speed = QPoint(0,0);
+             d->ticker.stop();
+             emit finished();
+            }
+
         }
         if(data->speed.x() || data->speed.y()) emit started();
     }
