@@ -33,7 +33,7 @@
 
 
 #ifdef Q_OS_SYMBIAN
-QString VERSION="0.5.8";
+QString VERSION="0.6.5";
 #endif
 
 QString URL_MAPS="http://pmetro.su/Maps.html";
@@ -41,13 +41,18 @@ QString URL_TRANSLATE="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
 
 bool LITE=0;
 int ICONSIZE=24; // begin size 100% scale
-QString TOOLBAR_STYLE=
-  "QToolButton,QToolButton:pressed,QLabel,QLineEdit{border:%7px solid grey;border-radius:%2px;background-color:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 rgba(255,255,255,60%));} "
-  "QToolButton{height:%1px;width:%1px;background-color:transparent;margin-top:%6px;margin-left:%6px;} "
-  "QToolButton:pressed{margin-top:%5px;margin-left:%5px;} "
-  "QLabel{color:black;font-weight:bold;padding:%7px;margin-left:%5px;} "
-  "QLineEdit{color:black;border-radius:%2px;height:%1px;font-weight:bold;padding-left:%6px;} "
-  "Sizes{size: 1%; size/2: %2; size/4: %3; size/6: %4; size/8: %5; size/10: %6; size/12: %7; }";
+QString STYLE_MAP_DEFAULT=
+  "QLabel,QLineEdit{color:black;font:bold;max-height:1.6em;border:0.05em solid grey;border-radius:0.3em;background:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 rgba(255,255,255,60%));} "
+  "QToolButton{border-image:url(:/img/button_inactive.png);height:%1px;width:%1px;background:transparent;padding:0.2em;margin-top:%6px;margin-left:%6px;} "
+  "QToolButton:pressed{border-image:url(:/img/button_active.png);margin-top:%5px;margin-left:%5px;} "
+//  "QLabel{padding-left:%7px;padding-right:%7px;margin-left:%5px;} "
+  "QLineEdit{padding-left:%6px;}",
+  STYLE_MAP=STYLE_MAP_DEFAULT;
+
+QString STYLE_MAIN_DEFAULT=
+  "QToolBox::tab{padding-left:1em;text-transform:uppercase;background:palette(button);border-bottom:0.2em solid palette(highlight);border-bottom-left-radius:0.5em;border-bottom-right-radius:0.5em;}"
+  "QToolBox::tab:selected{font:bold;border-bottom:0.3em solid palette(highlight);}",
+STYLE_MAIN=STYLE_MAIN_DEFAULT, SKIN_DEFAULT, STYLE_FONT_DEFAULT;
 
 MainWindow *mainWnd;
 
@@ -65,7 +70,7 @@ QVector <QString> IniGroupStr;
 QVector <QString> IniKeyStr;
 
 MainWindow::MainWindow(QWidget *parent) :
-    QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),Completer(NULL)
+QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NULL),Completer(NULL)
 {
 #if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN) || defined(Q_OS_ANDROID)
  MobileVersion=1;
@@ -79,9 +84,11 @@ MainWindow::MainWindow(QWidget *parent) :
  //setAttribute(Qt::WA_AutoOrientation);
  setAttribute(Qt::WA_AcceptTouchEvents);
  codePage = QTextCodec::codecForName("windows-1251");
+ SKIN_DEFAULT=this->style()->objectName();
+ STYLE_FONT_DEFAULT=qApp->font().toString();
  mainWnd=this;
  IniGroupStr << "MapView"<<"Main"<<"Other";
- IniKeyStr << "StationCustomFont"<<"StationFont"<<"StationBack"<<"StationShadow"<<"StationBackColor"<<"StationShadowColor"<<
+ IniKeyStr << "Skin"<<"StationCustomFont"<<"StationFont"<<"StationBack"<<"StationShadow"<<"StationBackColor"<<"StationShadowColor"<<
               "StationUpperCase"<<"StationWordWrap"<<"StationTransparency"<<
               "MapShowScrollbar"<<"WindowFullScreen"<<"MapShowTime"<<"MapShowBackground"<<"MapAntialiasing"<<"MapFastScrolling"<<
               "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale";
@@ -130,8 +137,10 @@ MainWindow::MainWindow(QWidget *parent) :
  cachePath=appPath+".cache/";
 
  // MOBILE NONNATIVE INTERFACE
- Config.appUiScale=2.5;
- qApp->setStyle("cleanlooks");
+ //Config.appUiScale=2.5;
+// qApp->setStyle("cleanlooks");
+// qApp->setStyleSheet(
+//         "QWidget{background:black;color:#e9e6e9;border:1px solid #151715;}QPushButton{min-width:7em;min-height:4ex;background:#2f322f;border-top-color:#3d3d3d;text-align:center;}QGroupBox{border-top:2px solid #3d3d3d;border-bottom:2px solid #3d3d3d;color:#e9e6e9;margin:1em;} QGroupBox::title{subcontrol-origin:margin;subcontrol-position:top center;}QCheckBox::indicator:unchecked{border:1px solid #e9e6e9;}" );
  MobileVersion=2;
 #endif
 #ifdef Q_OS_SYMBIAN
@@ -171,14 +180,16 @@ MainWindow::MainWindow(QWidget *parent) :
  Config.mapPosition=ini->value(key,QPoint()).toPoint();
  Config.mapPositionCheck=ini->contains(key);
 
- Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
+
  Config.appFirstStart=!ini->contains(IniKeyStr[ikMLastFile]);
- TOOLBAR_STYLE=ini->value("Styles",TOOLBAR_STYLE).toString();
+ //Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
  if(Config.locale.isEmpty()) Config.locale=QLocale::system().name().section("_",0,0);
  if(Config.locale=="uk" || Config.locale=="be" || Config.locale=="kk" || Config.locale=="ab" || Config.locale=="ky") Config.locale="ru";
+
  toggleLang(Config.locale);
 
  ui->setupUi(this); // UI #############################
+ loadSkin(ini->value("Skin").toString());
  //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
  showPageLoading();
  restoreState(QByteArray::fromHex(ini->value("WindowState").toByteArray()));
@@ -219,6 +230,18 @@ MainWindow::MainWindow(QWidget *parent) :
  menuBar()->addMenu(ui->menuSetting);
  menuBar()->addActions(ui->menuHelp->actions());
 #endif
+#ifdef Q_OS_ANDROID
+ ui->menuSetting->removeAction(ui->menuLanguage->menuAction());
+ menuBar()->removeAction(ui->menuInfo->menuAction());
+ menuBar()->removeAction(ui->menuView->menuAction());
+ menuBar()->removeAction(ui->menuHelp->menuAction());
+ menuBar()->removeAction(ui->menuFile->menuAction());
+ menuBar()->removeAction(ui->menuSetting->menuAction());
+ menuBar()->addActions(ui->menuFile->actions());
+ menuBar()->addMenu(ui->menuSetting);
+ menuBar()->addMenu(ui->menuLanguage);
+ menuBar()->addActions(ui->menuHelp->actions());
+#endif
 
 #ifdef QT_NO_DEBUG
  ui->menuView->menuAction()->setVisible(0);
@@ -254,7 +277,9 @@ if(LITE)
  connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
  if(!MobileVersion) // show description panel
    connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool)));
+
  connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
+ connect(map,SIGNAL(trackNames(QStringList)),this,SLOT(setTrackNames(QStringList)));
 
  ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
 
@@ -315,6 +340,10 @@ if(LITE)
  }else
   map->fitMap();
 
+ connect(ui->cbRoute,SIGNAL(currentIndexChanged(int)),map,SLOT(showTrack(int)));
+ connect(ui->mNextTrack,SIGNAL(triggered()),map,SLOT(showNextTrack()));
+ connect(ui->mPreviousTrack,SIGNAL(triggered()),map,SLOT(showPreviousTrack()));
+
  connect(ui->cbDelay,SIGNAL(currentIndexChanged(int)),map,SLOT(setDelayIndex(int)));
  connect(ui->sbDelay,SIGNAL(valueChanged(int)),map,SLOT(setDelayMetro(int)));
 
@@ -325,7 +354,8 @@ if(LITE)
  if(!LITE)
  {
   map->nodePopup = new QMenu(this);
-  map->nodePopup->addAction(new QAction(QIcon(":/img/dialog-information.png"),tr("Information"),this));
+  map->nodePopup->setStyleSheet(qApp->styleSheet());
+  map->nodePopup->addAction(new QAction(ui->mAbout->icon(),tr("Information"),this));
   connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1), SIGNAL(triggered()),this, SLOT(nodeInformation()));
   map->nodePopup->addSeparator();
   map->nodePopup->addAction(tr("Start"));
@@ -388,6 +418,7 @@ if(LITE)
  foreach(QWidget* w,widgets) w->setContextMenuPolicy(Qt::NoContextMenu);
 #endif
 
+
  ini->endGroup();
 
  if(Config.mapPositionCheck) // load map position
@@ -473,13 +504,17 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
    if(SettingsWindow) SettingsWindow->ui->retranslateUi(SettingsWindow);
 #ifdef Q_WS_MAEMO_5
    ui->mPreference->setText(ui->menuSetting->title());
+#endif
+#if defined(Q_OS_SYMBIAN) || defined(Q_OS_ANDROID)
+   QList<QMenu*> menus=findChildren<QMenu*>();
+   foreach(QMenu *m,menus) m->setTitle(m->title().remove("&"));
 #endif
    return 1;
   }
   break;
  case QEvent::Resize:
   {
-   if(map->selectedNode.count()) map->selectedNodesToFront(1);
+   map->selectedNodesToFront(1);
    map->mapStartDragging();
    //map->fitMap();
    return 1;
@@ -496,14 +531,16 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
     ui->mFullScreen->setChecked(0); //showMaximized();
     map->clearTrack();
    }
+
    if(key==Qt::Key_F1) on_mAbout_triggered();
    if(key==Qt::Key_F11) ui->mFullScreen->setChecked(windowState()!=Qt::WindowFullScreen);
    QString char_key=event->text().simplified();
-   if(!ui->mFind->isChecked() && !char_key.isEmpty())//((key>=Qt::Key_A && key<=Qt::Key_Z)||(key>=Qt::Key_0 && key<=Qt::Key_9)) )
+   //android menu:16777301
+   if(!ui->mFind->isChecked() && !char_key.isEmpty() && key!=16777301)//((key>=Qt::Key_A && key<=Qt::Key_Z)||(key>=Qt::Key_0 && key<=Qt::Key_9)) )
    {
     ui->mFind->setChecked(1);
-    ui->eSearch->setText(char_key);
     ui->eSearch->setFocus();
+    ui->eSearch->setText(char_key);
    }
    return 1;
   }
@@ -540,6 +577,16 @@ QString MainWindow::getMapDefaultDir()
  else  return map->params.mapFile.left(map->params.mapFile.lastIndexOf("/")+1);
 }
 
+//void MainWindow::scaleAndMoveMap(qreal scaleFactor,QPointF pos)
+//{
+//// if(MobileVersion && ui->stackMain->currentIndex()==1)
+//// {
+
+//// }
+// map->centerOn(pos);
+// map->scaleMap(scaleFactor);
+//}
+
 void MainWindow::openMap(QString fileName)
 {
  QFileDialog::Options options;
@@ -551,16 +598,12 @@ void MainWindow::openMap(QString fileName)
 // ZIPed maps will be unpacked and updated
  QDir Dir(MapPath);
  if (Dir.exists())
-  foreach(QFileInfo info, Dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Files))
+  foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
   {
-   QRegExp regExp=QRegExp("*.zip",Qt::CaseInsensitive,QRegExp::Wildcard);
-   if(info.isFile() && info.fileName().contains(regExp))
-   {
-    QFile::remove(info.absolutePath()+"/"+info.baseName()+".pmz");
-    removeDir(cachePath+info.baseName());
-    map->extractFiles(info.absoluteFilePath(),"*.pmz",MapPath);
-    QFile::remove(info.absoluteFilePath());
-   }
+   QFile::remove(info.absolutePath()+"/"+info.baseName()+".pmz");
+   removeDir(cachePath+info.baseName());
+   map->extractFiles(info.absoluteFilePath(),"*.pmz",MapPath);
+   QFile::remove(info.absoluteFilePath());
   }
 
 if(fileName.isEmpty())
@@ -595,6 +638,108 @@ if (fileName.isEmpty()) return;
  showPageMap();
 }
 
+void MainWindow::loadSkin(QString skinName)
+{
+ //qDebug() << skinName;
+ if(skinName.isEmpty()) skinName="Default";
+// if(skinName.isEmpty()) skinName=STYLE_APP_DEFAULT;
+ if(Config.appSkinName==skinName) return;
+
+ QString skinPath=appPath+"skin/";
+ QString fullPath=skinPath+skinName+"/";
+ QString styleSheet,value,url="url(",rc=":#(",args="/*%1%2%3%4%5%6%7*/";
+
+ // load default icons
+ if(actionIcons.count())
+ {
+  int i=0;
+  QList<QAction*> actions = findChildren<QAction*>();
+  foreach(QAction *a,actions) if(!a->objectName().isEmpty()) a->setIcon(actionIcons.at(i++));
+ }
+
+ // unpack skins
+ QDir Dir(skinPath);
+ if(Dir.exists())
+  foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
+  {
+    map->extractFiles(info.absoluteFilePath(),"*",skinPath);
+    QFile::remove(info.absoluteFilePath());
+  }
+
+ if(!QFile::exists(fullPath))
+ {
+  STYLE_MAIN=STYLE_MAIN_DEFAULT+args;
+  STYLE_MAP=STYLE_MAP_DEFAULT+args;
+
+  if(!QStyleFactory::keys().contains(skinName,Qt::CaseInsensitive))
+  {
+   if(this->style()->objectName()!=SKIN_DEFAULT) qApp->setStyle(SKIN_DEFAULT);
+   Config.appSkinName=SKIN_DEFAULT;
+  }
+  else
+  {
+   qApp->setStyle(skinName);
+   Config.appSkinName=skinName;
+  }
+  Config.appFont.fromString(STYLE_FONT_DEFAULT);
+  setScaleForUi(Config.appUiScale);
+  return;
+ }
+ Config.appSkinName=skinName;
+ QFile fileStyle;
+ styleSheet="";
+ fileStyle.setFileName(fullPath+"main.qss");
+ fileStyle.open(QFile::ReadOnly | QFile::Text);
+ styleSheet=fileStyle.readAll();
+ if(styleSheet.isEmpty()) styleSheet=STYLE_MAIN_DEFAULT;
+ styleSheet.replace(url+":",rc,Qt::CaseInsensitive);
+ styleSheet.replace(url,url+fullPath,Qt::CaseInsensitive);
+ styleSheet.replace(rc,url+":",Qt::CaseInsensitive);
+ STYLE_MAIN=styleSheet+args;
+ fileStyle.close();
+ styleSheet="";
+ fileStyle.setFileName(fullPath+"map.qss");
+ fileStyle.open(QFile::ReadOnly | QFile::Text);
+ styleSheet=fileStyle.readAll();
+ if(styleSheet.isEmpty()) styleSheet=STYLE_MAP_DEFAULT;
+ styleSheet.replace(url+":",rc,Qt::CaseInsensitive);
+ styleSheet.replace(url,url+fullPath,Qt::CaseInsensitive);
+ styleSheet.replace(rc,url+":",Qt::CaseInsensitive);
+ STYLE_MAP=styleSheet+args;
+ fileStyle.close();
+ QSettings ini(fullPath+"main.ini",QSettings::IniFormat);
+ ini.beginGroup("Main");
+ qApp->setStyle(ini.value("Style",SKIN_DEFAULT).toString());
+ value=ini.value("Font",STYLE_FONT_DEFAULT).toString().trimmed();
+ Config.appFont.fromString(value);
+ if(MobileVersion) Config.appFont.setPixelSize(ICONSIZE/2.6);
+ ini.endGroup();
+
+ setScaleForUi(Config.appUiScale);
+
+ ini.beginGroup("Icons");
+
+ if(!actionIcons.count() && ini.childKeys().count())
+ {
+  QList<QAction*> actions = findChildren<QAction*>();
+  foreach(QAction *a,actions) if(!a->objectName().isEmpty()) actionIcons << a->icon();
+ }
+
+ QList<QAction*> actions;
+ if(ini.childKeys().count()) actions = findChildren<QAction*>();
+ foreach(QString key,ini.childKeys())
+ {
+  value=ini.value(key).toString().trimmed();
+  if(value.isEmpty()) continue;
+  value=fullPath+value;
+  if(QFile::exists(value))
+   foreach(QAction *a,actions)
+    if(a->objectName().contains(key,Qt::CaseInsensitive)) { a->setIcon(QIcon(value)); break; }
+ }
+
+ ini.endGroup();
+}
+
 void MainWindow::on_mOpen_triggered()
 {
  openMap();
@@ -617,6 +762,7 @@ void MainWindow::on_eSearch_returnPressed()
 
 void MainWindow::on_mFind_toggled(bool checked)
 {
+ ui->eSearch->setFocus(); // just need
  if(!MobileVersion) // PC
  {
   map->mapStartDragging();
@@ -631,12 +777,37 @@ void MainWindow::on_mFind_toggled(bool checked)
  {
   //map->setUpdatesEnabled(0);
   ui->eSearch->setVisible(checked);
+  QApplication::processEvents();
+
+  // show virtual keyboard by click...
+  if(checked)
+  {
+   QPoint pos=QPoint(ui->eSearch->width()/2,ui->eSearch->height()/2);
+
+   QPoint global = ui->eSearch->mapToGlobal(pos);
+   QCursor::setPos(global);
+   QWidget *w = qobject_cast<QLineEdit*>(this->childAt(global));
+//   QWidget *w = qobject_cast<QLineEdit*>(qApp->widgetAt(global));
+   if(w)
+   {
+    //   QWidget *w = ui->eSearch->childAt(pos);
+    pos = w->mapFrom(ui->eSearch,pos);
+    //qDebug() << pos << global << w;
+    QMouseEvent mousePress(QEvent::MouseButtonPress, pos, Qt::LeftButton , Qt::LeftButton, Qt::NoModifier);
+    QApplication::sendEvent(w, &mousePress);
+    QMouseEvent mouseRelease(QEvent::MouseButtonRelease, pos, Qt::LeftButton , Qt::LeftButton, Qt::NoModifier);
+    QApplication::sendEvent(w, &mouseRelease);
+   }
+  }
   //(checked ? ui->eSearch->setMaximumWidth(maximumWidth()):ui->eSearch->setFixedWidth(0));
   //map->setUpdatesEnabled(1);
  }
-
+ if(checked)
+{
  ui->eSearch->setFocus();
  ui->eSearch->selectAll();
+}else
+ map->setFocus();
 }
 
 void MainWindow::on_bClear_clicked()
@@ -658,12 +829,33 @@ void MainWindow::setDelayNames(QStringList list)
  ui->cbDelay->setCurrentIndex(0);
 }
 
+
+void MainWindow::setTrackNames(QStringList list)
+{
+ if(MobileVersion) return;
+
+ QRegExp reCount=QRegExp(" (*)",Qt::CaseInsensitive,QRegExp::Wildcard);;
+ ui->cbRoute->clear();
+ ui->cbRoute->addItems(list);
+ if(ui->cbRoute->count())
+ {
+  QString routeCount=QString(" (%1)").arg(ui->cbRoute->count());
+  if(ui->gRoute->title().indexOf(reCount)==-1)
+       ui->gRoute->setTitle(ui->gRoute->title()+routeCount);
+  else ui->gRoute->setTitle(ui->gRoute->title().replace(reCount,routeCount));
+  ui->cbRoute->setCurrentIndex(0);
+  ui->cbRoute->setFocus();
+ }
+ else ui->gRoute->setTitle(ui->gRoute->title().replace(reCount,""));
+}
+
 void MainWindow::on_mAbout_triggered()
 {
  About *a=new About(0);
  if(MobileVersion)
  {
    toFullScreen();
+   a->setWindowFlags(Qt::Widget);
    ui->stackMain->addWidget(a);
    ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
    //a->showFullScreen();
@@ -684,19 +876,20 @@ void MainWindow::on_mPreference_triggered()
 #endif
  }
 
- //SettingWindow->loadSettingsToUi(AppConfig);
+ SettingsWindow->loadSettingsToUi(AppConfig);
 
  if(MobileVersion)
  {
-//#ifndef Q_WS_MAEMO_5
+#ifndef Q_WS_MAEMO_5
   connect(SettingsWindow,SIGNAL(showed()),this,SLOT(toFullScreen()));
   connect(SettingsWindow,SIGNAL(closed()),this,SLOT(showPageMap()));
   connect(SettingsWindow,SIGNAL(closed()),SettingsWindow,SLOT(close()));
+  SettingsWindow->setWindowFlags(Qt::Widget);
   ui->stackMain->addWidget(SettingsWindow);
   ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
-//#else
-//  SettingsWindow->show();
-//#endif
+#else
+  SettingsWindow->show();
+#endif
 
 
  //      MobileVersion==2 ? SettingWindow->showFullScreen():SettingWindow->showMaximized();
@@ -730,6 +923,10 @@ void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
   QFont TempFont=qApp->font();
   TempFont.setPixelSize(TempFont.pixelSize()/1.3);
   TextEdit->setFont(TempFont);
+  QPalette pal = TextEdit->palette();
+  pal.setBrush(QPalette::Base, mainWnd->palette().color(QPalette::Window));
+  pal.setColor(QPalette::Text,mainWnd->palette().color(QPalette::Text));
+  TextEdit->setPalette(pal);
  }
 
 #ifndef Q_WS_MAEMO_5
@@ -817,7 +1014,8 @@ void MainWindow::nodeInformation()
     MapScheme->params.mapColorBack=Qt::white;
     MapScheme->params.mapPath=map->params.mapPath;
     MapScheme->config.enableDrawBackground=1;
-    //work bad: MapScheme->config.enableKineticScroll=MapScheme->config.enableCaching;
+    //working bad//
+    MapScheme->config.enableKineticScroll=MapScheme->config.enableCaching;
     MapScheme->config.mapLastFile="";
     MapScheme->applyConfig();
 
@@ -877,6 +1075,7 @@ void MainWindow::nodeInformation()
   connect(DetailsWindow,SIGNAL(showed()),this,SLOT(toFullScreen()));
   connect(DetailsWindow->ui->bOK,SIGNAL(clicked()),this,SLOT(showPageMap()));
   connect(DetailsWindow->ui->bOK,SIGNAL(clicked()),DetailsWindow,SLOT(close()));
+  DetailsWindow->setWindowFlags(Qt::Widget);
   ui->stackMain->addWidget(DetailsWindow);
   ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
  }
@@ -922,7 +1121,7 @@ void MainWindow::closeEvent(QCloseEvent * e)
  if(ui->mSavePosition->isChecked())
       ini.setValue(key,QPoint(map->horizontalScrollBar()->value(),map->verticalScrollBar()->value()));
  else ini.remove(key);
- if(MobileVersion) ini.setValue("Styles",TOOLBAR_STYLE);
+ // -> create default skin? // if(MobileVersion) ini.setValue("Styles",MAP_STYLE);
  if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(cachePath);
  else
  if(map->config.enableCaching && !QFile::exists(map->params.mapPath+".cache"))
@@ -973,6 +1172,7 @@ void applySettings(const IniSettingMap &settings)
 
    switch(j.key())
    {
+   case ikSkin: mainWnd->loadSkin(value); break;
    case ikStationCustomFont: map->config.enableCustomFont=value.toInt(); break;
    case ikStationFont: nodeFont.fromString(value); break;
    case ikStationBack: map->config.enableStationBackColor=value.toInt(); break;
@@ -1085,20 +1285,31 @@ void loadSettings()
   //qDebug() << ">>" << group << IniGroupStr.indexOf(group);
   foreach(QString key, cfg.allKeys())
   {
-   //qDebug() << key << (IniKey)IniKeyStr.indexOf(key) << cfg.value(key).toString();
+//   qDebug() << key << (IniKey)IniKeyStr.indexOf(key) << cfg.value(key).toString();
    keys.insert((IniKey)IniKeyStr.indexOf(key),cfg.value(key).toString());
   }
   AppConfig.insert((IniGroup)IniGroupStr.indexOf(group),keys);
   cfg.endGroup();
  }
 
- applySettings(AppConfig);
+ /////////////
  if(AppConfig.value(igMapView).value(ikStationFont).isEmpty())
  {
-  IniKeyMap FontKey;
-  FontKey.insert(ikStationFont,map->params.nodeFont.toString());
-  AppConfig.insert(igMapView,FontKey);
+  IniKeyMap key=AppConfig.value(igMapView);
+  key.insert(ikStationFont,map->params.nodeFont.toString());
+  AppConfig.erase(AppConfig.find(igMapView));
+  AppConfig.insert(igMapView,key);
  }
+
+ if(AppConfig.value(igMain).value(ikSkin).isEmpty())
+ {
+  IniKeyMap key=AppConfig.value(igMain);
+  key.insert(ikSkin,mainWnd->Config.appSkinName);
+  AppConfig.erase(AppConfig.find(igMain));
+  AppConfig.insert(igMain,key);
+ }
+
+ applySettings(AppConfig);
  map->applyConfig();
 }
 
@@ -1211,10 +1422,18 @@ void MainWindow::setScaleForUi(qreal UiScale)
  if(font.pixelSize()>0)
       font.setPixelSize(font.pixelSize()*UiScale);
  else font.setPointSizeF(font.pointSizeF()*UiScale);
-
  qApp->setFont(font);
+ qApp->setStyleSheet(STYLE_MAIN.arg(Config.appIconSize)          // 1
+                                     .arg(int(Config.appIconSize/2))   // 2
+                                     .arg(int(Config.appIconSize/4))   // 3
+                                     .arg(int(Config.appIconSize/6))   // 4
+                                     .arg(int(Config.appIconSize/8))   // 5
+                                     .arg(int(Config.appIconSize/10))  // 6
+                                     .arg(int(Config.appIconSize/12)));// 7
+
  if(MobileVersion && mUi)
       mUi->setToolbarIconSize(Config.appIconSize);
  else ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
  Config.appUiScale=UiScale;
 }
+
