@@ -27,14 +27,16 @@ public:
     //void mousePressEvent(QGraphicsSceneMouseEvent *event);
     //void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
 
+    // params
     int ID;
-    QString Name,Alias,DisplayName;
+    QString Name,Alias;
     QRect Rect;
     int Height;
     TMapRoute *Route;
     NodeType TypeNode;
     QTextLayout *TextLayout;
 
+    // info
     enum InfoItemType{itText,itImage};
     struct InfoItem
     {
@@ -44,13 +46,19 @@ public:
 
     QMap <QString,InfoItem> Info;
 
+    // support
     bool HasTransfer;
+    bool HasInfo;
+    int Vertical,Align;
+    QString DisplayName;
+    QRect NRect,NRect90;
+    QRectF RectEllipse,RectBound;
+    QPainterPath PathNode,PathShape;
+
+    // cache
+    QString Distance;
+    QRectF TextRect,TextRectAdjustedTL,TextRectAdjustedBR;
 
-    int Vertical;
-    int Align;
-    QRect NRect,NRect90,EllipseRect;
-    int NodeWidth,NodeHeight;
-    QPainterPath PathNode;
 
 private:
     TMapView *Map;
