@@ -61,6 +61,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
   mapFade(NULL),nodePopup(NULL),mapWidth(0),mapHeight(0)
 {
  hide();
+ setStyleSheet("");
  setAttribute(Qt::WA_OpaquePaintEvent);
  setAttribute(Qt::WA_AcceptTouchEvents);
  viewport()->grabGesture(Qt::PinchGesture);
@@ -86,20 +87,29 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
 
 #ifdef Q_WS_MAEMO_5
  setAttribute(Qt::WA_Maemo5NonComposited);
-// if(winId()) // grab zoom keys - dont work... dont know why :(
-// {
-//  unsigned long val = 1; //grab
-//  Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
-//  if(atom)
-//   XChangeProperty(QX11Info::display(),winId(),atom,XA_INTEGER,32,
-//                   PropModeReplace,reinterpret_cast<unsigned char *>(&val),1);
-// }
 #endif
 
  config.locale=QLocale::system().name().section("_",0,0);
  initTranslit();
 
  scene = new QGraphicsScene(this);
+//qDebug() << 1;
+// QGraphicsWidget *widget = new QGraphicsWidget();
+// //widget.setLayout(scene->);
+// widget->setPos(0,0);
+//qDebug() << 2;
+// PannableView *pan=new PannableView(Qt::Vertical | Qt::Horizontal,800,480);
+/////QObject::connect(this, SIGNAL(), pannableView, SLOT(moveToItem(QGraphicsItem*)));
+//qDebug() << 3;
+// pan->setWidget(widget);
+// //scene->setActiveWindow(&widget);
+// scene->addItem( pan );
+// scene->setActiveWindow(widget);
+// scene->setActivePanel(widget);
+// //setParent((QWidget*)widget);
+// qDebug() << 4;
+//// setViewport((QWidget*)pan);
+
  //scene->setItemIndexMethod - setup later at load
  setOptimizationFlag(QGraphicsView::DontAdjustForAntialiasing);
  setOptimizationFlag(QGraphicsView::DontSavePainterState);
@@ -114,12 +124,14 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  //setViewportUpdateMode(FullViewportUpdate);
  //if(config.MobileVersion) setInteractive(0);
  setDragMode(QGraphicsView::ScrollHandDrag);
+#ifndef QML_EDITION
  setTransformationAnchor(AnchorUnderMouse);
+#endif
  setResizeAnchor(AnchorViewCenter);
 
  state.mapCached=0;
  state.mapDragging=0;
- params.delayIndex=params.delayMetro=0;
+ params.delayIndex=params.delayToMetro=0;
  params.appPath=AppPath;
  params.mapCachePath=CachePath;
  params.appName=qApp->applicationName();
@@ -152,6 +164,8 @@ void TMapView::mapStartDragging()
   }
   state.mapDragging=1;
  }
+// TimerPopup.stop();
+// fcharm->deactivateFrom(this);
  TimerDragging.start();
 }
 
@@ -165,10 +179,9 @@ void TMapView::mapStopDragging()
    {
     setRenderHints(Antialiasing);
     viewport()->update();
-    if(config.enableKineticScroll) fcharm->activateOn(this);
     //foreach(TMapNode *node,nodeByID) node->update(); // dont need in 4.7.2 ???
    }
-   //else
+//   if(config.enableKineticScroll) fcharm->activateOn(this);
   }
   state.mapDragging=0;
  }
@@ -187,13 +200,35 @@ void TMapView::keyPressEvent(QKeyEvent *event)
     case Qt::Key_Plus:
     case Qt::Key_ZoomIn:
     case Qt::Key_F7:
+    case 16777330: // android volUp
         scaleMap(qreal(1.2));
         break;
     case Qt::Key_Minus:
     case Qt::Key_ZoomOut:
     case Qt::Key_F8:
-        scaleMap(1/qreal(1.2));
+    case 16777328: // android volDown
+        scaleMap(qreal(0.8));
         break;
+    case Qt::Key_Right:
+     if(mapTrack.count()>1)
+     {
+      showNextTrack();
+      break;
+     }else
+     {
+      QGraphicsView::keyPressEvent(event);
+      break;
+     }
+    case Qt::Key_Left:
+     if(mapTrack.count()>1)
+     {
+      showPreviousTrack();
+      break;
+     }else
+     {
+      QGraphicsView::keyPressEvent(event);
+      break;
+     }
     case '*':
         (config.MobileVersion ? zoomIn():fitMap());
         break;
@@ -588,7 +623,6 @@ bool TMapView::extractFiles(QString zipFile, QString extractFiles, QString extra
   //separated mask: file.*;dir/file??.chk
   QStringList eList = extractFiles.split(";",QString::SkipEmptyParts);
 
-
   QList<UnZip::ZipEntry> zList = uz.entryList();
   foreach(const UnZip::ZipEntry& entry,zList)
    foreach(const QString &file, eList)
@@ -698,8 +732,8 @@ void TMapView::addPaintCmd(const QString &eParam,DrawType eType,QList<TPaintCmd>
    {
     loadMapImageToPaintCmd(param.at(0),paintCmd);
    }else
-    if(ext==".BMP" || ext==".GIF" || ext==".PNG")
-    {
+   if(ext==".BMP" || ext==".GIF" || ext==".PNG" || ext==".JPG") // some env don't support jpg
+   {
     cmd.image = new QPixmap(imageFile);
     cmd.type=dtImage;
     paintCmd << cmd;
@@ -997,6 +1031,7 @@ void TMapView::drawPaintCmd(QPainter *p,QList<TPaintCmd> &paintCmd)
 
 void TMapView::clearMap()
 {
+// qDebug() << "clear map";
  state.mapLoaded=0;
  state.mapCached=0;
 
@@ -1032,7 +1067,7 @@ void TMapView::clearMap()
    delete mapGraph[i][j];
    mapGraph[i][j]=NULL;
   }
- for(int i=0;i<mapGraph.count();i++) mapGraph[i].clear();;
+ for(int i=0;i<mapGraph.count();i++){ mapGraph[i].clear(); }
  mapGraph.clear();
 
  for(int i=0;i<layer.count();i++)
@@ -1602,8 +1637,8 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
 {
  QGraphicsView::mouseReleaseEvent(event);
 
- if(event->button()==Qt::LeftButton)
- {
+// if(event->button()==Qt::LeftButton)
+// {
 
 //  if(state.mapDragging)
 //  {
@@ -1619,7 +1654,7 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
 //   }
 //   state.mapDragging=0;
 //  }
- }
+// }
 //qDebug() << QLineF(nodeClickPos,event->pos()).length()<<params.nodeWidth*5;
  if(QLineF(nodeClickPos,event->pos()).length()>params.nodeWidth*5)
  {
@@ -1660,6 +1695,7 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
 void TMapView::selectedNodesToFront(bool enable)
 {
  if(!selectedNode.count()) return;
+ if(!enable && !mapFade->isVisible()) return;
 
  QRectF rect=selectedNode.at(0)->mapToScene(selectedNode.at(0)->boundingRect()).boundingRect();
  //qDebug() << rect;
@@ -1692,7 +1728,107 @@ void TMapView::selectedNodesToFront(bool enable)
  }
 }
 
-void TMapView::findTrack(TMapNode *begin,TMapNode *end)
+QString TMapView::getMessageTrackInfo(int index,bool inLine)
+{
+ if(!mapTrack.count()) return "";
+
+ QString info,br="<br>";
+ if(inLine)
+ {
+  info="%1 %2 %3 %4 %5 %6";
+ }
+ else
+ if(config.MobileVersion)
+ {
+  QString sp="&nbsp;";
+  info=sp+"%1 %2 %3"+sp+br+
+       sp+"%4 %5 %6"+sp;
+ }
+ else
+ {
+  info="<center><b>%1"+br+
+       "%2 %3</b>"+br+
+       "%4 %5 %6</center>"+br;
+ }
+
+ info=info.arg(inLine ? "":tr("Travel time")) // 1
+      .arg(QString::number(int(mapTrack.at(index).countSecond/60))) // 2
+      .arg(tr("min."))
+      .arg((mapTrack.at(index).countTransfer ? QString::number(mapTrack.at(index).countTransfer)+" "+tr("transf."):""))
+      .arg(QString::number(mapTrack.at(index).countStation))
+      .arg(tr("st."));
+
+ return info;
+}
+
+QString TMapView::getMessageTrackDescription(int index)
+{
+ if(!mapTrack.count()) return "";
+
+ QString tf="HH:mm";
+ QString br="<br>";
+ QString line=" "+tr("line")+")";
+ QString font="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b><td width=0 align=\"right\">%3</tr></table>";
+ QString smallTag="<small>%1</small>";
+
+ QString text=smallTag.arg("%4")+
+      font.arg("%5").arg("%6").arg(smallTag.arg("%8"))+
+      "<center>"+smallTag.arg("%7")+"</center><hr>";
+
+ text=text.arg(tr("Begin station:")) // 4
+          .arg(nodeByID[mapTrack.at(index).station.first().id]->Route->color.name()) //5
+          .arg(nodeByID[mapTrack.at(index).station.first().id]->DisplayName) //6
+          .arg("("+nodeByID[mapTrack.at(index).station.first().id]->Route->DisplayName+line) //7
+          .arg(mapTrack.at(index).station.first().time.toString(tf)); // 8
+
+ for(int i=1;i<mapTrack.at(index).station.count()-1;i++)
+ {
+  if(mapTrack.at(index).station.at(i).isTransfer)
+  {
+   text+=smallTag.arg(tr("Go to station:"))+
+         font.arg(nodeByID[mapTrack.at(index).station.at(i).id]->Route->color.name())
+         .arg(nodeByID[mapTrack.at(index).station.at(i).id]->DisplayName)
+         .arg("<b>"+smallTag.arg(mapTrack.at(index).station.at(i).time.toString(tf))+"</b>")+
+         smallTag.arg(tr("Transfer to station:"))+
+         font.arg(nodeByID[mapTrack.at(index).station.at(i+1).id]->Route->color.name())
+         .arg(nodeByID[mapTrack.at(index).station.at(i+1).id]->DisplayName)
+         .arg(smallTag.arg(mapTrack.at(index).station.at(i+1).time.toString(tf)))+"<hr>";
+  }
+
+ }
+
+ text+=smallTag.arg(tr("Final station:"))+
+       font.arg(nodeByID[mapTrack.at(index).station.last().id]->Route->color.name())
+           .arg(nodeByID[mapTrack.at(index).station.last().id]->DisplayName)
+           .arg("<b>"+smallTag.arg(mapTrack.at(index).station.last().time.toString(tf))+"</b>")+
+           "<center>"+smallTag.arg("("+nodeByID[mapTrack.at(index).station.last().id]->Route->DisplayName+line)+"</center>";
+
+ return text;
+}
+
+void TMapView::initWorkGraph(QVector< QVector<qreal> > &workGraph)
+{
+ int size=mapGraph.count();
+ workGraph.resize(size);
+ for(int i=0;i<size;i++)
+ {
+  workGraph[i].resize(size);
+  for(int j=0;j<size;j++)
+  {
+   if(mapGraph[i][j]) workGraph[i][j]=mapGraph[i][j]->cost;
+   else               workGraph[i][j]=0;
+
+   if(!config.MobileVersion && i==nodeBeginID && workGraph[i][j])
+    workGraph[i][j]+=params.delayToMetro*60+mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
+
+   if(i!=nodeBeginID && workGraph[i][j] && mapGraph[i][j]->type==TMapEdge::etTransfer)
+    workGraph[i][j]+=mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
+
+  }
+ }
+}
+
+void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal> > workGraph)
 {
  emit nodeClicked(1);
  if(!begin && end)
@@ -1711,59 +1847,47 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end)
   if(nodeBegin==NULL) nodeBegin=begin;
   else
   if(begin!=nodeBegin)nodeEnd=begin;
+
+  emit nodeHasInfo(nodeBegin && nodeBegin->HasInfo && !nodeEnd);
  }else
  {
   nodeBegin=begin;
   nodeEnd=end;
  }
 
+
  nodeBeginID=nodeBegin->ID;
  if(nodeEnd) nodeEndID=nodeEnd->ID;
- if(!nodeEnd)mapDistance.clear();
+ else        mapDistance.clear();
  //viewport()->repaint();
- qApp->processEvents();
- selectedNodesToFront(0);
+// qApp->processEvents();
 
  // calc distances
- if(begin!=nodeEnd)
+ if(begin!=nodeEnd || !workGraph.count())
  {
-  int size=mapGraph.count();
-  workGraph.resize(size);
-  for(int i=0;i<size;i++)
+//  qDebug() << "graph: " <<workGraph.count();
+  if(!workGraph.count()) // end node is changed
   {
-   workGraph[i].resize(size);
-   for(int j=0;j<size;j++)
-   {
-    if(mapGraph[i][j]) workGraph[i][j]=mapGraph[i][j]->cost;
-    else               workGraph[i][j]=0;
-
-    if(!config.MobileVersion && workGraph[i][j] && i==nodeBeginID)
-     workGraph[i][j]+=params.delayMetro*60+mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
-
-    if(workGraph[i][j] && mapGraph[i][j]->type==TMapEdge::etTransfer)
-     workGraph[i][j]+=mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
-
-   }
+   mapTrack.clear();
+   initWorkGraph(workGraph);
   }
-
-  // for(int i=0;i<workGraph.count();i++)
-  //  if(workGraph[nodeBeginID][i]!=NULL)
-  //   workGraph[nodeBeginID][i]+=param.delayMetro*60;
-
-  dijkstra(nodeBeginID);
-
-  // caching calculations
-  foreach(TMapNode *node,nodeByID) node->Distance=QString::number(int(mapDistance[node->ID]/60));
-
-  mapDistance[nodeBeginID]=params.delayMetro*60;
-
-  viewport()->update(); //foreach(TMapNode *node,nodeByID) node->update();
-
+  dijkstra(nodeBeginID,workGraph);
+  mapDistance[nodeBeginID]=params.delayToMetro*60;
  }
 
- emit nodeHasInfo(nodeBegin->HasInfo && nodeBegin && !nodeEnd);
- if(!nodeEnd) return;
- state.mapLoaded=0;
+ if(!nodeEnd) // just show time to all stations
+ {
+  // caching calculations
+  foreach(TMapNode *node,nodeByID)
+   if(mapDistance[node->ID]<INFINIT)
+        node->Distance=QString::number(int(mapDistance[node->ID]/60));
+   else node->Distance="";
+
+  viewport()->update(); //foreach(TMapNode *node,nodeByID) node->update();
+  return;
+ }
+
+
  // find track
  QList<int> id;
  int endID=nodeEndID;
@@ -1775,85 +1899,175 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end)
  }
 
  //qDebug() << id;
- mapStartDragging();
- selectedNode.clear();
- foreach(int i,id) selectedNode << nodeByID[i];
-
- selectedEdge.clear();
- for(int i=0;i<id.count()-1;i++)
-  selectedEdge << mapGraph[id.at(i)][id.at(i+1)];
-
- QString tf="HH:mm";
- QString br="<br>";
- QString line=" "+tr("line")+")";
- QString font="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b><td width=0 align=\"right\">%3</tr></table>";
- QString smallTag="<small>%1</small>";
-
- QString text=smallTag.arg("%4")+
-      font.arg("%5").arg("%6").arg(smallTag.arg("%8"))+
-      "<center>"+smallTag.arg("%7")+"</center><hr>";
-
- text=text.arg(tr("Begin station:")) // 4
-          .arg(nodeBegin->Route->color.name()) //5
-          .arg(nodeBegin->DisplayName) //6
-          .arg("("+nodeBegin->Route->DisplayName+line) //7
-          .arg(QTime::currentTime().addSecs(config.MobileVersion ? 0 : params.delayMetro*60+nodeBegin->Route->delay.at(params.delayIndex)).toString(tf)); // 8
-
  int countTransfer=0;
- for(int i=selectedEdge.count()-1;i>=0;i--)
+ TMapTrack track;
+ for(int i=id.count()-1;i>=0;i--)
  {
-  TMapEdge *edge=selectedEdge.at(i);
-  if(edge->type==TMapEdge::etTransfer)
+  track.selectedNode << nodeByID[id.at(i)];
+  track.idTrack+=QString::number(id.at(i))+"/";
+  track.addStantion(id.at(i)
+//                    ,nodeByID[id.at(i)]->DisplayName
+//                    ,nodeByID[id.at(i)]->Route->color
+                    ,QTime::currentTime().addSecs(mapDistance[id.at(i)]));
+ }
+ track.idTrack.chop(1);
+
+ for(int i=0,j=id.count()-2;i<id.count()-1 && j>=0;i++,j--) // asc & desc
+ {
+  track.selectedEdge << mapGraph[id.at(i)][id.at(i+1)];
+  track.station.at(j).isTransfer=(mapGraph[id.at(i)][id.at(i+1)]->type==TMapEdge::etTransfer) && workGraph[id.at(i)][id.at(i+1)];
+  track.station.at(j).isAlarm=track.station.at(j).isTransfer;
+  if(track.station.at(j).isTransfer)
   {
+   track.listAlarmTime << track.station.at(j).time;
    countTransfer++;
-   text+=smallTag.arg(tr("Go to station:"))+
-         font.arg(edge->node[1]->Route->color.name())
-             .arg(edge->node[1]->DisplayName)
-             .arg(smallTag.arg(QTime::currentTime().addSecs(mapDistance[edge->node[1]->ID]).toString(tf)))+
-         smallTag.arg(tr("Transfer to station:"))+
-         font.arg(edge->node[0]->Route->color.name())
-             .arg(edge->node[0]->DisplayName)
-             .arg(smallTag.arg(QTime::currentTime().addSecs(mapDistance[edge->node[0]->ID]).toString(tf)))+"<hr>";
   }
  }
+ track.station.last().isAlarm=1;
+ track.setParams(mapDistance[nodeEndID],track.selectedNode.count()-countTransfer,countTransfer);
 
- text+=smallTag.arg(tr("Final station:"))+
-       font.arg(nodeEnd->Route->color.name())
-           .arg(nodeEnd->DisplayName)
-           .arg(smallTag.arg(QTime::currentTime().addSecs(mapDistance[nodeEndID]).toString(tf)))+
-           "<center>"+smallTag.arg("("+nodeEnd->Route->DisplayName+line)+"</center>";
+// track.selectedNode << selectedNode;
+// track.selectedEdge << selectedEdge;
+ track.mapDistance << mapDistance;
 
- QString info;
- if(config.MobileVersion)
+ if(mapTrack.count())
  {
-  info="%1 %2 %3"+br+
-       "%4 %5 "+tr("st.");
- }else
- {
-  info="<center><b>%1</b>"+br+
-       "%2 %3"+br+
-       "%4 %5 "+tr("st.")+"</center>"+br;
+  if(track.countSecond<mapTrack.at(0).countSecond*2)
+  {
+   bool isExist=0;
+   foreach(TMapTrack t,mapTrack) if(t.idTrack==track.idTrack){ isExist=1; break; }
+   if(track.countStation>1 && !isExist) mapTrack << track;
+  }
  }
+ else mapTrack << track;
 
- info=info.arg(tr("Travel time")) // 1
-      .arg(QString::number(int(mapDistance[nodeEndID]/60))) // 2
-      .arg(tr("min."))
-      .arg((countTransfer ? QString::number(countTransfer)+" "+tr("transf."):""))
-      .arg(QString::number(selectedNode.count()-countTransfer));
+// QString testnames; foreach(TMapTrack::TStation s,track.station) testnames+=s.name+" ";
+// qDebug() << ">>> "+testnames+"\n"<< track.countStation << track.countTransfer << track.countSecond;
 
+// qDebug() << mapTrack.count() << countTransfer;
+ if(mapTrack.count()<9 && countTransfer && track.countSecond<mapTrack.at(0).countSecond*1.333) // count of tracks
+ {
+
+
+  for(int i=0;i<track.station.count()-1;i++)
+  {
+   if(!workGraph.count()) break;
+//   qDebug() << track.station.at(i).name << track.station.at(i).isTransfer;
+   if(track.station.at(i).isTransfer && workGraph[track.station.at(i).id][track.station.at(i+1).id])
+   {
+    qreal a,b;
+    a=workGraph[track.station.at(i).id][track.station.at(i+1).id];
+    b=workGraph[track.station.at(i+1).id][track.station.at(i).id];
+    workGraph[track.station.at(i).id][track.station.at(i+1).id]=0;
+    workGraph[track.station.at(i+1).id][track.station.at(i).id]=0;
+    findTrack(nodeBegin,nodeEnd,workGraph);
+    workGraph[track.station.at(i).id][track.station.at(i+1).id]=a;
+    workGraph[track.station.at(i+1).id][track.station.at(i).id]=b;
+   }
+  }
+
+  return;
+ }
+ else workGraph.clear();
+
+ // finding minimum count transfers and set to second
+ int min=1;
+ for(int i=1;i<mapTrack.count();i++)
+  if(mapTrack.at(i).countTransfer<=mapTrack.at(min).countTransfer)
+  {
+   if(mapTrack.at(i).countTransfer==mapTrack.at(min).countTransfer)
+   {
+    if(mapTrack.at(i).countSecond<mapTrack.at(min).countSecond) min=i;
+   }
+   else min=i;
+  }
+ if(mapTrack.count()>1 && mapTrack.at(0).countTransfer!=mapTrack.at(min).countTransfer) mapTrack.swap(1,min);
+
+ // sorting tracks after second
+ TMapTrack tmp;
+ int i,j,k;
+ for(i=2;i<mapTrack.count();i++)
+ {
+    k=i; tmp=mapTrack.at(i);
+    for(j=i+1;j<mapTrack.count();j++)
+      if (mapTrack.at(j).countSecond < tmp.countSecond) { k=j; tmp=mapTrack.at(j); }
+
+    mapTrack.swap(k,i);
+  }
+
+// qDebug() << "tracks: " << mapTrack.count();
+
+ QStringList trackList;
+ if(!config.MobileVersion)
+ {
+  for(int i=0;i<mapTrack.count();i++) trackList << QString::number(i+1)+") "+getMessageTrackInfo(i,1);
+ }
+ else
+ {
+  for(int i=0;i<mapTrack.count();i++) trackList << "";
+  showTrack(0);
+ }
+ emit trackNames(trackList);
+}
+
+void TMapView::showTrack(int i)
+{
+ if(i<0 || !mapTrack.count()) return;
+
+ state.mapLoaded=0;
+ QString info,text;
+ selectedNodesToFront(0); // previous trackIndex
+ selectedNode.clear();
+ selectedNode << mapTrack.at(i).selectedNode;
+// selectedNode.clear();
+// selectedEdge.clear();
+// mapDistance.clear();
+// selectedNode << track.selectedNode;
+// selectedEdge << track.selectedEdge;
+// mapDistance << track.mapDistance;
+ info=getMessageTrackInfo(i);
+ text=getMessageTrackDescription(i);
+// qDebug() << mapTrack.at(i).mapDistance;
+ // caching calculations
+ foreach(TMapNode *node,nodeByID)
+  if(mapTrack.at(i).mapDistance[node->ID]<INFINIT)
+       node->Distance=QString::number(int(mapTrack.at(i).mapDistance[node->ID]/60));
+  else node->Distance="";
+
+ emit nodeHasInfo(0);
  emit trackInfo(info);
  emit trackDescription(text);
  text=info+text;
  emit trackText(text);
  emit trackFinded(1);
 
+ mapStartDragging();
+ trackIndex=i;
  selectedNodesToFront(1);
  //qDebug() << id;
  state.mapLoaded=1;
+ viewport()->update();
+}
+
+void TMapView::showNextTrack()
+{
+ if(!mapTrack.count()) return;
+ int i=trackIndex+1;
+ if(i==4 || i==mapTrack.count())  i=0;
+ showTrack(i);
+}
+
+void TMapView::showPreviousTrack()
+{
+ if(!mapTrack.count()) return;
+ int i=trackIndex-1;
+ if(i==-1)  i=(mapTrack.count()<4 ? mapTrack.count()-1:3);
+ showTrack(i);
 }
 
 void TMapView::clearTrack()
 {
+// qDebug() << "clear track";
  nodeBeginID=-1;
  nodeEndID=-1;
  if(nodeBegin) nodeBegin->update();
@@ -1862,19 +2076,22 @@ void TMapView::clearTrack()
  nodeEnd=NULL;
  nodeClick=NULL;
  selectedNodesToFront(0);
- selectedNode.clear();
- selectedEdge.clear();
+ mapTrack.clear();
+ trackIndex=0;
  //if(nodeByID.count()) foreach(TMapNode *node,nodeByID) node->update();
  emit trackText("");
  emit nodeClicked(0);
  emit nodeHasInfo(0);
+
  if(config.MobileVersion) emit trackFinded(0); // hide LabelInfo
- viewport()->repaint();
+ else                     emit trackNames(QStringList()); // clear list of routes
+ // viewport()->repaint();
+ viewport()->update();
 }
 
 
 
-void TMapView::dijkstra(int nodeBeginID)
+void TMapView::dijkstra(int nodeBeginID, QVector< QVector<qreal> > &workGraph)
 {
  QQueue<QPair<int,int> > queue;
  QPair <int,int> qtmp;
@@ -1965,7 +2182,7 @@ void TMapView::defaultConfig()
  if(!QFile::exists(config.mapLastFile))
  {
   QDir Dir=QDir(params.appPath+mapDir,"*.pmz",QDir::Name,QDir::Files);
-  config.mapLastFile=params.appPath+mapDir+Dir.entryList().first();
+  if(!Dir.entryList().empty()) config.mapLastFile=params.appPath+mapDir+Dir.entryList().first();
  }
  //qDebug() << config.mapLastFile;
  config.enableCustomFont=0;
@@ -2030,13 +2247,15 @@ void TMapView::applyConfig()
 
 void TMapView::setDelayMetro(int delay)
 {
- params.delayMetro=delay;
+// workGraph.clear();
+ params.delayToMetro=delay;
  if(nodeEnd) findTrack(nodeBegin,nodeEnd);
  else
  if(nodeBegin) findTrack(nodeBegin);
 }
 void TMapView::setDelayIndex(int index)
 {
+// workGraph.clear();
  params.delayIndex=index;
  if(nodeEnd) findTrack(nodeBegin,nodeEnd);
  else
@@ -2069,11 +2288,18 @@ QString TMapView::convertToTextWithTags(QString text)
  while(index != -1)
  {
   QString StrUrl=url.cap();
-  if(StrUrl.right(1)==",") StrUrl.chop(1);
+  char lastSymbol=StrUrl.right(1).toAscii().at(0);
+  if(lastSymbol==',' || lastSymbol=='.') StrUrl.chop(1);
   int UrlLength=StrUrl.length();
 
-  TagText.replace(index+offset,UrlLength,QString("<a href=\"%1\">%2</a> ").arg(StrUrl).arg(QUrl::fromEncoded(StrUrl.toAscii()).toString()));
-  offset+=UrlLength+16;
+  QString LinkName=QUrl::fromEncoded(StrUrl.toAscii()).toString();
+  LinkName.replace("http://www.","",Qt::CaseInsensitive);
+  LinkName.replace("http://","",Qt::CaseInsensitive);
+  lastSymbol=LinkName.right(1).toAscii().at(0);
+  if(lastSymbol=='/') LinkName.chop(1);
+
+  TagText.replace(index+offset,UrlLength,QString("<a href=\"%1\">").arg(StrUrl) + QString("%1</a>").arg(LinkName));
+  offset+=LinkName.length()+15; //+ count symbols of tag
   StrUrl.fill('x');
   text.replace(index,UrlLength,StrUrl);
   index=text.indexOf(url);
@@ -2170,10 +2396,14 @@ void TMapView::saveToFile()
 {
  if(!QImageWriter::supportedImageFormats().count()) return;
 
+ QList<QByteArray> formats;
+ formats << QImageWriter::supportedImageFormats();
+ if(formats.contains("jpg")) formats.move(formats.indexOf("jpg"),0);
+ if(formats.contains("png")) formats.move(formats.indexOf("png"),0);
  QString supportFormats;
- foreach(QString ext,QImageWriter::supportedImageFormats())
+ foreach(QString ext,formats)
   supportFormats+=QString("%1 (*.%2);;").arg(ext.toUpper()).arg(ext);
-\
+
  QString filter=supportFormats.left(supportFormats.indexOf(";;")),
          fileName=QFileDialog::getSaveFileName(0, tr("Save file"), params.appPath,
                                                supportFormats,&filter);
@@ -2277,7 +2507,7 @@ void TMapView::convertToTranslit(QString &text)
 
 void TMapView::findedNodesToFront(QList<int> NodeID)
 {
- if(selectedEdge.count()) return;
+ if(mapTrack.count() &&  mapTrack.at(trackIndex).selectedEdge.count()) return;
  selectedNodesToFront(0);
  selectedNode.clear();
  foreach(int ID,NodeID) selectedNode << nodeByID[ID];
@@ -2313,7 +2543,16 @@ bool TMapView::viewportEvent(QEvent *event)
   return true;
  }
  case QEvent::Gesture:
-  return gestureEvent(static_cast<QGestureEvent*>(event));
+  if(QGesture *gesture=((QGestureEvent*)event)->gesture(Qt::PinchGesture))
+  {
+   QPinchGesture::ChangeFlags changeFlags = ((QPinchGesture*)gesture)->changeFlags();
+   if(changeFlags & QPinchGesture::ScaleFactorChanged)
+   {
+    scaleMap(((QPinchGesture*)gesture)->scaleFactor());
+    nodeClick=NULL;
+   }
+  }
+  return true;
  break;
 
  default:
@@ -2321,28 +2560,3 @@ bool TMapView::viewportEvent(QEvent *event)
  }
 }
 
-bool TMapView::gestureEvent(QGestureEvent *event)
-{
- if (QGesture *pinch = event->gesture(Qt::PinchGesture)){
-  //if(config.enableKineticScroll) fcharm->deactivateFrom(this);
-  pinchTriggered(static_cast<QPinchGesture *>(pinch));
-  //if(config.enableKineticScroll) fcharm->activateOn(this);
- }
- return true;
-}
-
-void TMapView::pinchTriggered(QPinchGesture *gesture)
-{
- QPinchGesture::ChangeFlags changeFlags = gesture->changeFlags();
- if (changeFlags & QPinchGesture::ScaleFactorChanged)
- {
-//  qreal value = gesture->scaleFactor();
-//  qreal zoom = value*zoomFactor();
-
-//  if(zoom < 20 && zoom > 0.1) setZoomFactor(zoom);
-
-  scaleMap(gesture->scaleFactor());
-
-  nodeClick=NULL;
- }
-}
