@@ -6,11 +6,12 @@
 #include "flickcharm.h"
 
 extern MainWindow *mainWnd;
-extern QString TOOLBAR_STYLE;
+extern QString STYLE_MAP,SKIN_DEFAULT;
 //extern TMapView *map;
 
 TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
 {Q_UNUSED(parent);
+ Ui::MainWindow *ui=mainWnd->ui;
  int Spacing=mainWnd->Config.appIconSize/4;
  DefaultIconSize=QSize(mainWnd->Config.appIconSize,mainWnd->Config.appIconSize);
 
@@ -19,28 +20,40 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
  lLeft =new QVBoxLayout;
  lRight =new QVBoxLayout;
  lToolbar =new QGridLayout;
- bZoomOut = new QToolButton(this);
- bZoomIn = new QToolButton(this);
- bFit = new QToolButton(this);
- bSave = new QToolButton(this);
- bZoomOut->setIcon(QIcon(":/img/zoom-out.png"));
- bZoomIn->setIcon(QIcon(":/img/zoom-in.png"));
- bFit->setIcon(QIcon(":/img/zoom-fit-best.png"));
- bSave->setIcon(QIcon(":/img/document-save.png"));
+
+ if(type) // details
+ {
+  bZoomOut = new QToolButton(this);
+  bZoomIn = new QToolButton(this);
+  bFit = new QToolButton(this);
+  bSave = new QToolButton(this);
+  bZoomOut->setIcon(ui->mZoomOut->icon());
+  bZoomIn->setIcon(ui->mZoomIn->icon());
+  bFit->setIcon(ui->mFit->icon());
+  bSave->setIcon(ui->mSave->icon());
+  connect(bSave,SIGNAL(clicked()),map,SLOT(saveToFile()));
+  connect(bZoomOut,SIGNAL(clicked()),map,SLOT(zoomOut()));
+  connect(bZoomIn,SIGNAL(clicked()),map,SLOT(zoomIn()));
+  connect(bFit,SIGNAL(clicked()),map,SLOT(fitMap()));
+ }
+ else
+ {
+  bZoomOut = createButtonFromAction(ui->mZoomOut);
+  bZoomIn = createButtonFromAction(ui->mZoomIn);
+  bFit = createButtonFromAction(ui->mFit);
+  bSave = createButtonFromAction(ui->mSave);
+  bNext =  createButtonFromAction(ui->mNextTrack);
+  bPrevious = createButtonFromAction(ui->mPreviousTrack);
+ }
+
  bZoomOut->setAutoRepeat(1);
  bZoomIn->setAutoRepeat(1);
  bZoomOut->setShortcut(QKeySequence::ZoomOut);
  bZoomIn->setShortcut(QKeySequence::ZoomIn);
- connect(bSave,SIGNAL(clicked()),map,SLOT(saveToFile()));
- connect(bZoomOut,SIGNAL(clicked()),map,SLOT(zoomOut()));
- connect(bZoomIn,SIGNAL(clicked()),map,SLOT(zoomIn()));
- connect(bFit,SIGNAL(clicked()),map,SLOT(fitMap()));
- bSave->setVisible(mainWnd->ui->mSave->isVisible());
+ bSave->setVisible(ui->mSave->isVisible());
 
  if(!type) // MobileVersion UI
  {
-  Ui::MainWindow *ui=mainWnd->ui;
-
   lTop->addWidget(createButtonFromAction(ui->mFind));
   lTop->addSpacing(Spacing);
   ui->eSearch->setVisible(0);
@@ -60,12 +73,12 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   lRight->addWidget(bClear);
   bClear->setVisible(0);
 
-  bInfo=createButtonFromAction(new QAction(QIcon(":/img/dialog-information.png"),tr("Information"),this));
+  bInfo=createButtonFromAction(new QAction(ui->mAbout->icon(),tr("Information"),this));
   bInfo->setVisible(0);
 
   textInfo = new QLabel("");
   QFont TempFont=qApp->font();
-  TempFont.setPixelSize(TempFont.pixelSize()/1.5);
+  TempFont.setPixelSize(TempFont.pixelSize()/1.25);
   textInfo->setFont(TempFont);
   textInfo->setMinimumWidth(0);
   textInfo->setMinimumHeight(0);
@@ -74,10 +87,24 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   textInfo->setVisible(0);
   textInfo->installEventFilter(this);
 
+  QString transparentButton="QToolButton{margin-right:-0.5em;margin-left:-0.5em;padding:0em;border-image:url();background:transparent;}";
+  QHBoxLayout *InfoLayout = new QHBoxLayout;
+//  ui->bClear->setCursor(Qt::ArrowCursor);
+  bNext->setStyleSheet(transparentButton);
+  bPrevious->setStyleSheet(transparentButton);
+  InfoLayout->setSpacing(0);
+  InfoLayout->setMargin(0);
+  InfoLayout->addWidget(bPrevious);
+  InfoLayout->addStretch();
+//  InfoLayout->addWidget(textInfo);
+  InfoLayout->addWidget(bNext);
+  textInfo->setLayout(InfoLayout);
+
   lBottom->addWidget(bFit);
   lBottom->addSpacing(Spacing);
   lBottom->addStretch();
   lBottom->addWidget(bInfo);
+//  lBottom->addItem(InfoLayout);
   lBottom->addWidget(textInfo);
   lBottom->addStretch();
   lBottom->addSpacing(Spacing);
@@ -91,10 +118,30 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
 //  pal.setBrush(QPalette::Window, palette().color(QPalette::Window)); // fix white background
 //  Description->setPalette(pal);
 //  Description->setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
+  bNextDescription =  createButtonFromAction(ui->mNextTrack);
+  bPreviousDescription = createButtonFromAction(ui->mPreviousTrack);
+
   LabelInfo = new QLabel(Description);
   LabelInfo->setAlignment(Qt::AlignHCenter);
+
+  transparentButton="QToolButton{border-image:url();background:transparent;}";
+  QHBoxLayout *InfoDescriptionLayout = new QHBoxLayout;
+//  ui->bClear->setCursor(Qt::ArrowCursor);
+  bNextDescription->setStyleSheet(transparentButton);
+  bPreviousDescription->setStyleSheet(transparentButton);
+  InfoDescriptionLayout->setSpacing(0);
+  InfoDescriptionLayout->setMargin(0);
+  InfoDescriptionLayout->addWidget(bPreviousDescription);
+  InfoDescriptionLayout->addStretch();
+  InfoDescriptionLayout->addWidget(bNextDescription);
+  LabelInfo->setLayout(InfoDescriptionLayout);
+
 //  LabelInfo->setStyleSheet("font-weight:bold;");
   TextDesc= new QTextBrowser(Description);
+  QPalette pal=TextDesc->palette();
+  pal.setBrush(QPalette::Base, mainWnd->palette().color(QPalette::Window));
+  pal.setColor(QPalette::Text,mainWnd->palette().color(QPalette::Text));
+  TextDesc->setPalette(pal);
   TempFont=qApp->font();
   TempFont.setPixelSize(TempFont.pixelSize()/1.2);
   TextDesc->setFont(TempFont);
@@ -118,10 +165,13 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
 
   //  bZoomIn->setShortcut(QKeySequence(Qt::Key_F7));
   //  bZoomOut->setShortcut(QKeySequence(Qt::Key_F8));
-  QIcon icoFullScreen=QIcon::fromTheme(QLatin1String("general_fullsize"));
-  if(!icoFullScreen.isNull()) ui->mFullScreen->setIcon(icoFullScreen);
-  QIcon icoClose=QIcon::fromTheme(QLatin1String("general_close"));
-  if(!icoClose.isNull()) ui->mExit->setIcon(icoClose);
+  if(mainWnd->Config.appSkinName==SKIN_DEFAULT)
+  {
+   QIcon icoFullScreen=QIcon::fromTheme(QLatin1String("general_fullsize"));
+   if(!icoFullScreen.isNull()) ui->mFullScreen->setIcon(icoFullScreen);
+   QIcon icoClose=QIcon::fromTheme(QLatin1String("general_close"));
+   if(!icoClose.isNull()) ui->mExit->setIcon(icoClose);
+  }
   ui->textDescription->setTextInteractionFlags(Qt::TextSelectableByKeyboard);
 #else
  FlickCharm *fcharm = new FlickCharm(TextDesc);
@@ -142,6 +192,8 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   connect(map,SIGNAL(nodeHasInfo(bool)),bInfo,SLOT(setVisible(bool)));
   connect(bInfo,SIGNAL(clicked()),mainWnd,SLOT(nodeInformation()));
   connect(map,SIGNAL(trackFinded(bool)),textInfo,SLOT(setVisible(bool)));
+  connect(map,SIGNAL(trackNames(QStringList)),this,SLOT(setTrackListVisible(QStringList)));
+
   connect(map,SIGNAL(trackInfo(QString)),textInfo,SLOT(setText(QString)));
   connect(bFullscreen,SIGNAL(toggled(bool)),bExit,SLOT(setVisible(bool)));
   connect(ui->mFind,SIGNAL(toggled(bool)),map->scene,SLOT(update()));
@@ -171,6 +223,14 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
  map->setLayout(lToolbar);
  setToolbarIconSize(mainWnd->Config.appIconSize);
 
+//bFit->setObjectName(ui->mFit->objectName());
+//bExit->setObjectName(ui->mExit->objectName());
+//bFullscreen->setObjectName(ui->mFullScreen->objectName());
+//bClear->setObjectName(ui->mClear->objectName());
+//bInfo->setObjectName(ui->mAbout->objectName());
+//bZoomOut->setObjectName(ui->mZoomOut->objectName());
+//bZoomIn->setObjectName(ui->mZoomIn->objectName());
+
 }
 TMobileUi::~TMobileUi()
 {
@@ -190,7 +250,7 @@ void TMobileUi::setToolbarIconSize(int Size)
 {
  if(!bZoomOut) return;
  QSize IconSize=QSize(Size,Size);
- MapView->setStyleSheet(TOOLBAR_STYLE.arg(Size)          // 1
+ MapView->setStyleSheet(STYLE_MAP.arg(Size)          // 1
                                      .arg(int(Size/2))   // 2
                                      .arg(int(Size/4))   // 3
                                      .arg(int(Size/6))   // 4
@@ -224,3 +284,10 @@ bool TMobileUi::eventFilter(QObject *obj, QEvent *event)
  else return QObject::eventFilter(obj, event);
 
 }
+
+void TMobileUi::setTrackListVisible(QStringList trackList)
+{
+ bool visible=trackList.count()>1;
+ bNext->setVisible(visible);
+ bPrevious->setVisible(visible);
+}
