@@ -20,6 +20,7 @@ public slots:
 
 private slots:
  void hideSearch(bool state);
+ void setTrackListVisible(QStringList trackList);
 
 private:
  QToolButton* createButtonFromAction(QAction *Action,bool AutoRepeat=0);
@@ -40,7 +41,10 @@ private:
  QToolButton *bFit;
  QToolButton *bClear;
  QToolButton *bInfo;
-
+ QToolButton *bNext;
+ QToolButton *bPrevious;
+ QToolButton *bNextDescription;
+ QToolButton *bPreviousDescription;
  TMapView *MapView;
 
  QWidget *Description;
